package com.zd.chemical.mapper;

import java.util.List;
import com.zd.chemical.domain.ActAuditconfig;

/**
 * 工作流审批Mapper接口
 *
 * @author zd
 * @date 2022-08-16
 */
public interface ActAuditconfigMapper
{
    /**
     * 查询工作流审批
     *
     * @param id 工作流审批主键
     * @return 工作流审批
     */
    ActAuditconfig selectActAuditconfigById(Long id);

    /**
     * 查询工作流审批列表
     *
     * @param actAuditconfig 工作流审批
     * @return 工作流审批集合
     */
    List<ActAuditconfig> selectActAuditconfigList(ActAuditconfig actAuditconfig);

    /**
     * 根据主键集合查询工作流审批列表
     *
     * @param ids 主键集合
     * @return 工作流审批集合
     */
    List<ActAuditconfig> getListByIds(List <Long> ids);

    /**
     * 新增工作流审批
     *
     * @param actAuditconfig 工作流审批
     * @return 结果
     */
    int insertActAuditconfig(ActAuditconfig actAuditconfig);

    /**
     * 修改工作流审批
     *
     * @param actAuditconfig 工作流审批
     * @return 结果
     */
    int updateActAuditconfig(ActAuditconfig actAuditconfig);

    /**
     * 删除工作流审批
     *
     * @param id 工作流审批主键
     * @return 结果
     */
    int deleteActAuditconfigById(Long id);

    /**
     * 批量删除工作流审批
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteActAuditconfigByIds(Long[] ids);


    /**
     * 删除工作流审批
     *
     * @return 结果
     */
    int deleteActAuditconfigByAll();
}
